==> mosaicode-1.0.3.dev3.tar.gz: mosaicode-1.0.3.dev3/mosaicode/persistence/codetemplatepersistence.py <==
# -*- coding: utf-8 -*-
# ----------------------------------------------------------------------
"""
This module contains the CodeTemplatePersistence class.
"""
import os
import inspect  # For module inspect
import pkgutil  # For dynamic package load
from os.path import expanduser
from mosaicode.utils.XMLUtils import XMLParser
from mosaicode.utils.PythonUtils import PythonParser
from mosaicode.model.codetemplate import CodeTemplate

tag_name = "MosaicodeCodeTemplate"

class CodeTemplatePersistence():
    """
    This class contains methods related the CodeTemplatePersistence class.
    """

    # ----------------------------------------------------------------------
    @classmethod
    def load(cls, file_name):
        """
        This method loads the code_template from XML file.

        Returns:

            * **Types** (:class:`boolean<boolean>`)
        """
        # load the code_template
        if os.path.exists(file_name) is False:
            return None
        parser = XMLParser(file_name)

        if parser.getTag(tag_name) is None:
            return None

        try:
            code_template = CodeTemplate()
            code_template.name = parser.getTagAttr(tag_name,  "name")
            code_template.type = parser.getTagAttr(tag_name,  "type")
            code_template.description = parser.getTagAttr(tag_name,  "description")
            code_template.language = parser.getTagAttr(tag_name,  "language")
            code_template.command = parser.getTag(tag_name).getTag("command").getText()
            code_template.extension = parser.getTagAttr(tag_name,  "extension")
            code_template.code = parser.getTag(tag_name).getTag("code").getText()

            code_parts = parser.getTag(tag_name).getTag("code_parts").getChildTags("code_part")
            for code_part in code_parts:
                code_template.code_parts.append(code_part.getAttr("value"))

        except Exception as e:
            print e
            return None

        if code_template.name == "":
            return None
        return code_template

    # ----------------------------------------------------------------------
    @classmethod
    def save(cls, code_template):
        """
        This method save the code_template in user space.

        Returns:

            * **Types** (:class:`boolean<boolean>`)
        """
        from mosaicode.system import System
        code_template.source = "xml"
        parser = XMLParser()
        parser.addTag(tag_name)
        parser.setTagAttr(tag_name,'name', code_template.name)
        parser.setTagAttr(tag_name,'type', code_template.type)
        parser.setTagAttr(tag_name,'description', code_template.description)
        parser.setTagAttr(tag_name,'language', code_template.language)
        parser.setTagAttr(tag_name,'extension', code_template.extension)
        parser.appendToTag(tag_name,'command').string = str(code_template.command)
        parser.appendToTag(tag_name,'code').string = str(code_template.code)

        parser.appendToTag(tag_name, 'code_parts')
        for key in code_template.code_parts:
            parser.appendToTag('code_parts', 'code_part', value=key.strip())

        try:
            data_dir = System.get_user_dir() + "/extensions/"
            data_dir = data_dir + code_template.language + "/"
            if not os.path.isdir(data_dir):
                try:
                    os.makedirs(data_dir)
                except:
                    pass
            file_name = data_dir + code_template.type + ".xml"
            code_template_file = file(os.path.expanduser(file_name), 'w')
            code_template_file.write(parser.prettify())
            code_template_file.close()
        except IOError as e:
            return False
        return True

    # ----------------------------------------------------------------------
    @classmethod
    def save_python(cls, code_template):
        """
        This method save the codetemplate in user space in python extension.

        Returns:

            * **Types** (:class:`boolean<boolean>`)
        """
        from mosaicode.system import System
        parser = PythonParser()
        parser.class_name = code_template.name.replace(' ', '')
        parser.dependencies = [{'from':'mosaicode.model.codetemplate', 'import':'CodeTemplate'}]
        parser.inherited_classes = ['CodeTemplate']
        parser.setAttribute('type', code_template.type)
        parser.setAttribute('name', code_template.name)
        parser.setAttribute('description', code_template.description)
        parser.setAttribute('language', code_template.language)
        parser.setAttribute('command', code_template.command)
        parser.setAttribute('extension', code_template.extension)
        parser.setAttribute('code', code_template.code)
        parser.setAttribute('code_parts', code_template.code_parts)

        try:
            data_dir = System.get_user_dir() + "/extensions/"
            data_dir = data_dir + code_template.language + "/"
            if not os.path.isdir(data_dir):
                try:
                    os.makedirs(data_dir)
                except:
                    pass
            file_name = data_dir + code_template.name.lower().replace(' ', '_') + ".py"
            parser.save(file_name)
        except IOError as e:
            return False
        return True
# ----------------------------------------------------------------------

==> mosaicode-1.0.4.dev1.tar.gz: mosaicode-1.0.4.dev1/mosaicode/persistence/codetemplatepersistence.py <==
# -*- coding: utf-8 -*-
# ----------------------------------------------------------------------
"""
This module contains the CodeTemplatePersistence class.
"""
import os
import inspect  # For module inspect
import pkgutil  # For dynamic package load
from os.path import expanduser
from mosaicode.utils.XMLUtils import XMLParser
from mosaicode.utils.PythonUtils import PythonParser
from mosaicode.model.codetemplate import CodeTemplate
from mosaicode.persistence.persistence import Persistence


class CodeTemplatePersistence():
    """
    This class contains methods related the CodeTemplatePersistence class.
    """

    tag_name = "MosaicodeCodeTemplate"
    properties = ["name", "type", "description",
                  "language", "command", "extension", "code"]

    # ----------------------------------------------------------------------
    @classmethod
    def load_xml(cls, file_name):
        """
        This method loads the code_template from XML file.

        Returns:

            * **Types** (:class:`boolean<boolean>`)
        """
        # load the code_template
        if os.path.exists(file_name) is False:
            return None
        parser = XMLParser(file_name)

        if parser.getTag(CodeTemplatePersistence.tag_name) is None:
            return None
        ct = parser.getTag(CodeTemplatePersistence.tag_name)

        code_template = CodeTemplate()
        for prop in CodeTemplatePersistence.properties:
            if hasattr(ct, prop) and hasattr(code_template, prop):
                code_template.__dict__[prop] = parser.getTagAttr(
                    CodeTemplatePersistence.tag_name, prop)

        code_parts = parser.getTag(CodeTemplatePersistence.tag_name).getTag(
            "code_parts").getChildTags("code_part")
        for code_part in code_parts:
            code_template.code_parts.append(code_part.getAttr("value"))

        if code_template.name == "":
            return None
        return code_template

    # ----------------------------------------------------------------------
    @classmethod
    def save_xml(cls, code_template, path):
        """
        This method save the code_template in user space.

        Returns:

            * **Types** (:class:`boolean<boolean>`)
        """
        code_template.source = "xml"
        parser = XMLParser()
        parser.addTag(CodeTemplatePersistence.tag_name)

        for prop in CodeTemplatePersistence.properties:
            if hasattr(code_template, prop):
                parser.setTagAttr(CodeTemplatePersistence.tag_name,
                                  prop, code_template.__dict__[prop])

        parser.appendToTag(CodeTemplatePersistence.tag_name, 'code_parts')
        for key in code_template.code_parts:
            parser.appendToTag('code_parts', 'code_part', value=key.strip())

        if not Persistence.create_dir(path):
            return False
        try:
            file_name = path + code_template.type + ".xml"
            code_template_file = file(os.path.expanduser(file_name), 'w')
            code_template_file.write(parser.prettify())
            code_template_file.close()
        except IOError as e:
            return False
        return True

    # ----------------------------------------------------------------------
    @classmethod
    def save_python(cls, code_template, path):
        """
        This method save the codetemplate in user space in python extension.

        Returns:

            * **Types** (:class:`boolean<boolean>`)
        """
        parser = PythonParser()
        parser.class_name = code_template.name.replace(' ', '')
        parser.dependencies = [
            {'from': 'mosaicode.model.codetemplate', 'import': 'CodeTemplate'}]
        parser.inherited_classes = ['CodeTemplate']
        parser.setAttribute('name', code_template.name)
        parser.setAttribute('description', code_template.description)
        parser.setAttribute('language', code_template.language)
        parser.setAttribute('command', code_template.command)
        parser.setAttribute('extension', code_template.extension)
        parser.setAttribute('code', code_template.code)
        parser.setAttribute('code_parts', code_template.code_parts)

        if not Persistence.create_dir(path):
            return False

        file_name = path + code_template.name.lower().replace(' ', '_') + ".py"
        try:
            parser.save(file_name)
        except IOError as e:
            return False
        return True
# ----------------------------------------------------------------------
